==> v26.0.11rc2.tar.gz: nextcloud/apps/updatenotification/l10n/is.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} er í boði. Fáðu frekari upplýsingar um hvernig á að uppfæra.",
    "Channel updated" : "Rás uppfærð",
    "Web updater is disabled" : "Vefuppfærsla er óvirk",
    "Update notifications" : "Tilkynningar um uppfærslu",
    "The update server could not be reached since %d days to check for new updates." : "Ekki hefur verið hægt að nálgast uppfærsluþjóninn í %d daga til að athuga með nýjar uppfærslur.",
    "Please check the Nextcloud and server log files for errors." : "Skoðaðu hvort einhver villuboð séu í annálaskrám Nextcloud þjónsins.",
    "Update to %1$s is available." : "Uppfærsla fyrir %1$s er tiltæk.",
    "Update to {serverAndVersion} is available." : "Uppfærsla í {serverAndVersion} er tiltæk.",
    "Update for {app} to version %s is available." : "Uppfærsla fyrir {app} í útgáfu %s er tiltæk.",
    "Update notification" : "Tilkynning um uppfærslu",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Birtir tilkynningar um uppfærslur fyrir Nextcloud og sér um SSO-innskráningu fyrir uppfærslustýringuna.",
    "Update" : "Uppfæra",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Útgáfunni sem þú ert að keyra er ekki legur viðhaldið. Uppfærðu í studda útgáfu við fyrsta tækifæri.",
    "Apps missing compatible version" : "Forrit sem vantar samhæfða útgáfu",
    "View in store" : "Skoða í hugbúnaðarsafni",
    "Apps with compatible version" : "Forrit með samhæfða útgáfu",
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Athugaðu að ekki er mælt með því að nota vefuppfærsluna á fleiri en 100 notendur! Endilega notaðu uppfærslu af skipanalínu í staðinn!",
    "Open updater" : "Opna uppfærslustýringu",
    "Download now" : "Sækja núna",
    "What's new?" : "Hvað er nýtt á döfinni?",
    "View changelog" : "Skoða breytingaannál",
    "The update check is not yet finished. Please refresh the page." : "Athugun á uppfærslum er ekki ennþá lokið. Endurlestu síðuna.",
    "Your version is up to date." : "Útgáfan þín er af nýjustu gerð.",
    "A non-default update server is in use to be checked for updates:" : "Uppfærsluþjónn sem ekki er sjálfgefinn er núna í notkun til að athuga með uppfærslur:",
    "Update channel" : "Uppfærslurás",
    "Current update channel:" : "Núverandi uppfærslurás:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Þú getur alltaf uppfært í nýrri útgáfu. En þú getur aldrei niðurfært í stöðugri útgáfu.",
    "Notify members of the following groups about available updates:" : "Tilkynna meðlimum eftirfarandi hópa um tiltækar uppfærslur:",
    "No groups" : "Engir hópar",
    "Only notifications for app updates are available." : "Eingöngu eru eru tiltækar tilkynningar fyrir uppfærslur forrita.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Valda uppfærslurásin gerir úreltar sértækar tilkynningar fyrir vefþjóninn.",
    "The selected update channel does not support updates of the server." : "Valda uppfærslurásin styður ekki uppfærslur fyrir vefþjóninn.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Ný útgáfa er tiltæk: <strong>{newVersionString}</strong>",
    "Checking apps for compatible versions" : "Athuga forrit vegna samhæfðra uppfærslna",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Gakktu úr skugga um að í config.php sé <samp>appstoreenabled</samp> ekki sett sem ósatt/false.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Gat ekki tengst við forritabúðina eða að í henni eru engar uppfærslur. Leitaðu handvirkt að uppfærslum, eða gakktu úr skugga um að þjónninn þinn sé með aðgang að internetinu og geti tengst forritabúðinni.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>Öll</strong> forrit eru með tiltækar uppfærslur fyrir þessa útgáfu Nextcloud.",
    "Enterprise" : "Fyrirtæki",
    "Stable" : "Stöðug",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Nýjasta stöðuga útgáfan. Hún hentar fyrir alla venjulega notkun og er alltaf uppfærð í nýjustu aðalútgáfu.",
    "Beta" : "BETA-prófunarútgáfa",
    "A pre-release version only for testing new features, not for production environments." : "For-útgáfa sem einungis er hugsuð til að prófa nýja eiginleika, og er alls ekki ætluð fyrir alvöru vinnslu.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> forrit er með tiltæka uppfærslu fyrir þessa útgáfu Nextcloud.","<strong>%n</strong> forrit eru ekki með neina tiltæka uppfærslu fyrir þessa útgáfu Nextcloud."],
    "Please use the command line updater to update." : "Endilega notaðu uppfærslu af skipanalínu.",
    "Update channel:" : "Uppfærslurás:",
    "Checked on {lastCheckedDate}" : "Athugað þann {lastCheckedDate}"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> v28.0.1rc1.tar.gz: nextcloud/apps/updatenotification/l10n/is.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} er í boði. Fáðu frekari upplýsingar um hvernig á að uppfæra.",
    "Channel updated" : "Rás uppfærð",
    "Web updater is disabled" : "Vefuppfærsla er óvirk",
    "Update notifications" : "Tilkynningar um uppfærslu",
    "The update server could not be reached since %d days to check for new updates." : "Ekki hefur verið hægt að nálgast uppfærsluþjóninn í %d daga til að athuga með nýjar uppfærslur.",
    "Please check the Nextcloud and server log files for errors." : "Skoðaðu hvort einhver villuboð séu í annálaskrám Nextcloud þjónsins.",
    "Update to %1$s is available." : "Uppfærsla fyrir %1$s er tiltæk.",
    "Update to {serverAndVersion} is available." : "Uppfærsla í {serverAndVersion} er tiltæk.",
    "Update for {app} to version %s is available." : "Uppfærsla fyrir {app} í útgáfu %s er tiltæk.",
    "Update notification" : "Tilkynning um uppfærslu",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Birtir tilkynningar um uppfærslur fyrir Nextcloud og sér um SSO-innskráningu fyrir uppfærslustýringuna.",
    "Update" : "Uppfæra",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Útgáfunni sem þú ert að keyra er ekki legur viðhaldið. Uppfærðu í studda útgáfu við fyrsta tækifæri.",
    "Apps missing compatible version" : "Forrit sem vantar samhæfða útgáfu",
    "View in store" : "Skoða í hugbúnaðarsafni",
    "Apps with compatible version" : "Forrit með samhæfða útgáfu",
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Athugaðu að ekki er mælt með því að nota vefuppfærsluna á fleiri en 100 notendur! Endilega notaðu uppfærslu af skipanalínu í staðinn!",
    "Open updater" : "Opna uppfærslustýringu",
    "Download now" : "Sækja núna",
    "What's new?" : "Hvað er nýtt á döfinni?",
    "View changelog" : "Skoða breytingaannál",
    "The update check is not yet finished. Please refresh the page." : "Athugun á uppfærslum er ekki ennþá lokið. Endurlestu síðuna.",
    "Your version is up to date." : "Útgáfan þín er af nýjustu gerð.",
    "A non-default update server is in use to be checked for updates:" : "Uppfærsluþjónn sem ekki er sjálfgefinn er núna í notkun til að athuga með uppfærslur:",
    "Update channel" : "Uppfærslurás",
    "Current update channel:" : "Núverandi uppfærslurás:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Þú getur alltaf uppfært í nýrri útgáfu. En þú getur aldrei niðurfært í stöðugri útgáfu.",
    "Notify members of the following groups about available updates:" : "Tilkynna meðlimum eftirfarandi hópa um tiltækar uppfærslur:",
    "No groups" : "Engir hópar",
    "Only notifications for app updates are available." : "Eingöngu eru eru tiltækar tilkynningar fyrir uppfærslur forrita.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Valda uppfærslurásin gerir úreltar sértækar tilkynningar fyrir vefþjóninn.",
    "The selected update channel does not support updates of the server." : "Valda uppfærslurásin styður ekki uppfærslur fyrir vefþjóninn.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Ný útgáfa er tiltæk: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "Athugað þann {lastCheckedDate}",
    "Checking apps for compatible versions" : "Athuga forrit vegna samhæfðra uppfærslna",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Gakktu úr skugga um að í config.php sé <samp>appstoreenabled</samp> ekki sett sem ósatt/false.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Gat ekki tengst við forritabúðina eða að í henni eru engar uppfærslur. Leitaðu handvirkt að uppfærslum, eða gakktu úr skugga um að þjónninn þinn sé með aðgang að internetinu og geti tengst forritabúðinni.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>Öll</strong> forrit eru með tiltækar uppfærslur fyrir þessa útgáfu Nextcloud.",
    "Enterprise" : "Fyrirtæki",
    "Stable" : "Stöðug",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Nýjasta stöðuga útgáfan. Hún hentar fyrir alla venjulega notkun og er alltaf uppfærð í nýjustu aðalútgáfu.",
    "Beta" : "BETA-prófunarútgáfa",
    "A pre-release version only for testing new features, not for production environments." : "For-útgáfa sem einungis er hugsuð til að prófa nýja eiginleika, og er alls ekki ætluð fyrir alvöru vinnslu.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> forrit er með tiltæka uppfærslu fyrir þessa útgáfu Nextcloud.","<strong>%n</strong> forrit eru ekki með neina tiltæka uppfærslu fyrir þessa útgáfu Nextcloud."],
    "Please use the command line updater to update." : "Endilega notaðu uppfærslu af skipanalínu.",
    "Update channel:" : "Uppfærslurás:"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
